[PATCH v6 8/9] drm/xe/guc: Add GuC log to devcoredump captures

John.C.Harrison at Intel.com John.C.Harrison at Intel.com
Fri Aug 30 06:23:09 UTC 2024


From: John Harrison <John.C.Harrison at Intel.com>

Include the GuC log in devcoredump captures because they can be useful
with debugging certain types of bug.

v2: Fix kerneldoc
v3: Drop module parameter as now using more compact ascii85 encoding
rather than hexdump (although still not compressed) (review feedback
from Matthew B). Rebase onto recent refactoring of devcoredump code.

Signed-off-by: John Harrison <John.C.Harrison at Intel.com>
---
 drivers/gpu/drm/xe/xe_devcoredump.c       | 26 +++++++++++++++--------
 drivers/gpu/drm/xe/xe_devcoredump_types.h | 14 +++++++-----
 2 files changed, 26 insertions(+), 14 deletions(-)

diff --git a/drivers/gpu/drm/xe/xe_devcoredump.c b/drivers/gpu/drm/xe/xe_devcoredump.c
index eec7b89ab48b..bb3f91130d86 100644
--- a/drivers/gpu/drm/xe/xe_devcoredump.c
+++ b/drivers/gpu/drm/xe/xe_devcoredump.c
@@ -18,8 +18,10 @@
 #include "xe_gt.h"
 #include "xe_gt_printk.h"
 #include "xe_guc_ct.h"
+#include "xe_guc_log.h"
 #include "xe_guc_submit.h"
 #include "xe_hw_engine.h"
+#include "xe_module.h"
 #include "xe_sched_job.h"
 #include "xe_vm.h"
 
@@ -97,9 +99,11 @@ static ssize_t __xe_devcoredump_read(char *buffer, size_t count,
 	drm_printf(&p, "Process: %s\n", ss->process_name);
 	xe_device_snapshot_print(xe, &p);
 
+	drm_printf(&p, "\n**** GuC Log ****\n");
+	xe_guc_log_snapshot_print(coredump->snapshot.guc.log, &p);
 	drm_printf(&p, "\n**** GuC CT ****\n");
-	xe_guc_ct_snapshot_print(coredump->snapshot.ct, &p);
-	xe_guc_exec_queue_snapshot_print(coredump->snapshot.ge, &p);
+	xe_guc_ct_snapshot_print(coredump->snapshot.guc.ct, &p);
+	xe_guc_exec_queue_snapshot_print(coredump->snapshot.guc.ge, &p);
 
 	drm_printf(&p, "\n**** Job ****\n");
 	xe_sched_job_snapshot_print(coredump->snapshot.job, &p);
@@ -119,11 +123,14 @@ static void xe_devcoredump_snapshot_free(struct xe_devcoredump_snapshot *ss)
 {
 	int i;
 
-	xe_guc_ct_snapshot_free(ss->ct);
-	ss->ct = NULL;
+	xe_guc_log_snapshot_free(ss->guc.log);
+	ss->guc.log = NULL;
 
-	xe_guc_exec_queue_snapshot_free(ss->ge);
-	ss->ge = NULL;
+	xe_guc_ct_snapshot_free(ss->guc.ct);
+	ss->guc.ct = NULL;
+
+	xe_guc_exec_queue_snapshot_free(ss->guc.ge);
+	ss->guc.ge = NULL;
 
 	xe_sched_job_snapshot_free(ss->job);
 	ss->job = NULL;
@@ -147,7 +154,7 @@ static void xe_devcoredump_deferred_snap_work(struct work_struct *work)
 	if (xe_force_wake_get(gt_to_fw(ss->gt), XE_FORCEWAKE_ALL))
 		xe_gt_info(ss->gt, "failed to get forcewake for coredump capture\n");
 	xe_vm_snapshot_capture_delayed(ss->vm);
-	xe_guc_exec_queue_snapshot_capture_delayed(ss->ge);
+	xe_guc_exec_queue_snapshot_capture_delayed(ss->guc.ge);
 	xe_force_wake_put(gt_to_fw(ss->gt), XE_FORCEWAKE_ALL);
 
 	/* Calculate devcoredump size */
@@ -248,8 +255,9 @@ static void devcoredump_snapshot(struct xe_devcoredump *coredump,
 	if (xe_force_wake_get(gt_to_fw(q->gt), XE_FORCEWAKE_ALL))
 		xe_gt_info(ss->gt, "failed to get forcewake for coredump capture\n");
 
-	coredump->snapshot.ct = xe_guc_ct_snapshot_capture(&guc->ct, true);
-	coredump->snapshot.ge = xe_guc_exec_queue_snapshot_capture(q);
+	coredump->snapshot.guc.log = xe_guc_log_snapshot_capture(&guc->log, true);
+	coredump->snapshot.guc.ct = xe_guc_ct_snapshot_capture(&guc->ct, true);
+	coredump->snapshot.guc.ge = xe_guc_exec_queue_snapshot_capture(q);
 	coredump->snapshot.job = xe_sched_job_snapshot_capture(job);
 	coredump->snapshot.vm = xe_vm_snapshot_capture(q->vm);
 
diff --git a/drivers/gpu/drm/xe/xe_devcoredump_types.h b/drivers/gpu/drm/xe/xe_devcoredump_types.h
index 440d05d77a5a..f68d2cba187d 100644
--- a/drivers/gpu/drm/xe/xe_devcoredump_types.h
+++ b/drivers/gpu/drm/xe/xe_devcoredump_types.h
@@ -34,11 +34,15 @@ struct xe_devcoredump_snapshot {
 	/** @work: Workqueue for deferred capture outside of signaling context */
 	struct work_struct work;
 
-	/* GuC snapshots */
-	/** @ct: GuC CT snapshot */
-	struct xe_guc_ct_snapshot *ct;
-	/** @ge: Guc Engine snapshot */
-	struct xe_guc_submit_exec_queue_snapshot *ge;
+	/** @guc: GuC related snapshots */
+	struct {
+		/** @guc.ct: GuC CT snapshot */
+		struct xe_guc_ct_snapshot *ct;
+		/** @guc.log: GuC log snapshot */
+		struct xe_guc_log_snapshot *log;
+		/** @guc.ge: Guc Engine snapshot */
+		struct xe_guc_submit_exec_queue_snapshot *ge;
+	} guc;
 
 	/** @hwe: HW Engine snapshot array */
 	struct xe_hw_engine_snapshot *hwe[XE_NUM_HW_ENGINES];
-- 
2.46.0



More information about the Intel-xe mailing list